View source: R/get_data_OBDAP.R
| get_data_OBDAP | R Documentation |
get_data_OBDAP function retrieves data from one or more Italian regions using ISTAT region codes. It allows filtering based on: municipality code, and the project's starting and/or ending dates. Additionally, it provides geospatial references.
get_data_OBDAP(
cod_reg,
cod_prov = NULL,
cod_mun = NULL,
start = NULL,
end = NULL,
geo_ref = NULL,
soil_defense = FALSE,
verbose = TRUE
)
cod_reg |
character vector. The ISTAT regional code is used to specify one or more regions of interest when retrieving data. (See |
cod_prov |
character vector. The ISTAT province code is used to specify one or more provinces of interest when retrieving data. (See |
cod_mun |
character vector The ISTAT municipal code is used to specify one or more municipalities of interest when retrieving data. (See |
start |
character (format YYYY-mm-dd). Effective starting date of design refers to the specific phase of a public project that marks the beginning of its design process. This date can be of interest for filtering and analyzing relevant data. |
end |
character (format YYYY-mm-dd). Effective ending date of design refers to the specific phase of a public project that marks the conclusion of its design process. This date can be of interest for filtering and analyzing relevant data. |
geo_ref |
character. The georeference data can be specified using the |
soil_defense |
logical. By default set to |
verbose |
Logic value (TRUE or FALSE). Toggle warnings and messages. If 'verbose = TRUE' (default) the function prints on the screen some messages describing the progress of the tasks. If 'verbose = FALSE' any message about the progression is suppressed. |
Object of class data.frame showing 22 variables.Descriptive Variables:
Local Project Code (character)
CUP (character)
Intervention (character)
Financial Variables:
State Funding (numeric)
EU Funding (numeric)
Local Authorities Funding (numeric)
Private Funding (numeric)
Other Funding (numeric)
Geographical References:
DEN_REGION (character)
DEN_PROVINCE (character)
DEN_MUNICIPALITY (character)
COD_REGION (character)
COD_PROVINCE (character)
COD_MUNICIPALITY (character)
geom (character)
Legislative process main steps:
Executive Design Starting Date (character)
Executive Design Ending Date (character)
Works Execution Starting Date (character)
Works Execution Ending Date (character)
Conclusion Starting Date (character)
Conclusion Ending Date (character)
Operability (character)
Lorena Ricciotti
data <- get_data_OBDAP("14")
# Retrieve data for one region filtering for soil defense interventions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.