The get_data_region_OC function retrieves data from one or more Italian regions using associated region codes. It offers filtering options based on project start/end dates, province, and municipality codes. Additionally, it provides geospatial references.
get_data_region_OC(
cod_reg,
cod_prov = NULL,
cod_mun = NULL,
start = NULL,
end = NULL,
geo_ref = NULL,
soil_defense = FALSE,
verbose = TRUE
)Object of classe data.frame showing 42 variables:
Descriptive Variables:
Local Project Code (character)
CUP (character)
Intervention (character)
Financial Variables:
EU Funding (numeric)
FESR EU Funding (numeric)
FSE EU Funding (numeric)
FEASR EU Funding (numeric)
FEAMP EU Funding (numeric)
IOG EU Funding (numeric)
Fondo di Rotazione ITA (numeric)
FSC ITA Funding (numeric)
PAC ITA Funding (numeric)
Completamenti ITA Funding (numeric)
Other Measures ITA Funding (numeric)
Region Funding (numeric)
Province Funding (numeric)
Municipality Funding (numeric)
Released Resources (numeric)
Other Public Funding (numeric)
Foreign State Funding (numeric)
Private Funding (numeric)
Total Public Funding (numeric)
Total Funding (numeric)
Geographical References:
DEN_REGION (character)
DEN_PROVINCE (character)
DEN_MUNICIPALITY (character)
COD_REGION (character)
COD_PROVINCE (character)
COD_MUNICIPALITY (character)
geom (character)
Legislative process main steps:
Feasibility Study Starting Date (character)
Feasibility Study Ending Date (character)
Preliminary Design Starting Date (character)
Preliminary Design Ending Date (character)
Definitive Design Starting Date (character)
Definitive Design Ending Date (character)
Executive Design Starting Date (character)
Executive Design Ending Date (character)
Effective Design Starting Date (character)
Effective Design Ending Date (character)
Works Execution Starting Date (character)
Works Execution Ending Date (character)
Conclusion Starting Date (character)
Conclusion Ending Date (character)
character. Vector specifying one or more region of interest. To get information about the codes associated to each region use the function get_info_OC
character. The ISTAT province code is used to filter data based on one or more specific provinces of interest.(See get_codes function)
character. The ISTAT municipality code is used to filter data based on one or more specific provinces of interest.(See get_codes function)
(format YYYY-mm-dd). Effective starting date of the project. This date can be of interest for filtering and analyzing relevant data.
(format YYYY-mm-dd). Effective ending date of the project. This date can be of interest for filtering and analyzing relevant data.
character, The georeference data can be specified using the geo_ref argument. If set to A, the function returns shape polygons of each municipality. If set to C, it retrieves the coordinates of the centroids of each municipality.
Logical. By default set to FALSE. If only soil defense data are of interest set the argument to TRUE.
Logic value (TRUE or FALSE). Toggle warnings and messages. If 'verbose = TRUE' (default) the function prints on the screen some messages describing the progress of the tasks. If 'verbose = FALSE' any message about the progression is suppressed.
Lorena Ricciotti
dati_VDA <- get_data_region_OC("VDA", cod_mun = "007002")
# #Retrieving data for the municipality with code 007002 in the Valle d'Aosta region.
Run the code above in your browser using DataLab