| merge_data | R Documentation |
Function to merge the three financial datasets from the three different platforms to obtain a complete dataset to have a comprhensive overview of the investements.
merge_data(data_RENDIS, data_OBDAP, data_OC)
data_RENDIS |
Dataset of class 'data.frame'. Specify the dataset obtained from the ReNDiS database by the |
data_OBDAP |
Dataset of class 'data.frame'. Specify the dataset obtained from the OpenBDAP database by the |
data_OC |
Dataset of class 'data.frame'. Specify the dataset obtained from the OpenCoesione database by the |
Object of class data.frame showing 28 variables:
Descriptive Variables:
CUP (character)
Intervention (character)
Source (character)
Financial Variables:
State Funding (numeric)
EU Funding (numeric)
Local Authorities Funding (numeric)
Private Funding (numeric)
Other Funding (numeric)
Finance (numeric)
Geographical References:
DEN_REGION (character)
DEN_PROVINCE (character)
DEN_MUNICIPALITY (character)
COD_REGION (character)
COD_PROVINCE (character)
COD_MUNICIPALITY (character)
geom (character)
Legislative process main steps:
Feasibility Study Starting Date (character)
Feasibility Study Ending Date (character)
Preliminary Design Starting Date (character)
Preliminary Design Ending Date (character)
Definitive Design Starting Date (character)
Definitive Design Ending Date (character)
Executive Design Starting Date (character)
Executive Design Ending Date (character)
Works Execution Starting Date (character)
Works Execution Ending Date (character)
Conclusion Starting Date (character)
Conclusion Ending Date (character)
Lorena Ricciotti
data(OCpoint)
data(OBDAPpoint)
data(RENDISpoint)
data_all <- merge_data(RENDISpoint, OBDAPpoint, OCpoint)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.